@@ -40,6 +40,7 @@ from .type_defs import (
     BatchDetectKeyPhrasesResponseTypeDef,
     BatchDetectSentimentResponseTypeDef,
     BatchDetectSyntaxResponseTypeDef,
+    BatchDetectTargetedSentimentResponseTypeDef,
     ClassifyDocumentResponseTypeDef,
     ContainsPiiEntitiesResponseTypeDef,
     CreateDocumentClassifierResponseTypeDef,
@@ -64,6 +65,7 @@ from .type_defs import (
     DetectPiiEntitiesResponseTypeDef,
     DetectSentimentResponseTypeDef,
     DetectSyntaxResponseTypeDef,
+    DetectTargetedSentimentResponseTypeDef,
     DocumentClassificationJobFilterTypeDef,
     DocumentClassifierFilterTypeDef,
     DocumentClassifierInputDataConfigTypeDef,
@@ -226,6 +228,17 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#batch_detect_syntax)
         """
 
+    def batch_detect_targeted_sentiment(
+        self, *, TextList: Sequence[str], LanguageCode: LanguageCodeType
+    ) -> BatchDetectTargetedSentimentResponseTypeDef:
+        """
+        Inspects a batch of documents and returns a sentiment analysis for each entity
+        identified in the documents.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.batch_detect_targeted_sentiment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#batch_detect_targeted_sentiment)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -243,6 +256,14 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#classify_document)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#close)
+        """
+
     def contains_pii_entities(
         self, *, Text: str, LanguageCode: LanguageCodeType
     ) -> ContainsPiiEntitiesResponseTypeDef:
@@ -260,14 +281,14 @@ class ComprehendClient(BaseClient):
         *,
         DocumentClassifierName: str,
         DataAccessRoleArn: str,
-        InputDataConfig: "DocumentClassifierInputDataConfigTypeDef",
+        InputDataConfig: DocumentClassifierInputDataConfigTypeDef,
         LanguageCode: LanguageCodeType,
         VersionName: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
-        OutputDataConfig: "DocumentClassifierOutputDataConfigTypeDef" = ...,
+        Tags: Sequence[TagTypeDef] = ...,
+        OutputDataConfig: DocumentClassifierOutputDataConfigTypeDef = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
+        VpcConfig: VpcConfigTypeDef = ...,
         Mode: DocumentClassifierModeType = ...,
         ModelKmsKeyId: str = ...,
         ModelPolicy: str = ...
@@ -286,13 +307,14 @@ class ComprehendClient(BaseClient):
         ModelArn: str,
         DesiredInferenceUnits: int,
         ClientRequestToken: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         DataAccessRoleArn: str = ...
     ) -> CreateEndpointResponseTypeDef:
         """
         Creates a model-specific endpoint for synchronous inference for a previously
-        trained custom model See also: [AWS API
-        Documentation](https://docs.aws.amazon.com/goto/WebAPI/comprehend-2017-11-27/CreateEndpoint).
+        trained custom model For information about endpoints, see [Managing
+        endpoints](https://docs.aws.amazon.com/comprehend/latest/dg/manage-
+        endpoints.html)_ .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#create_endpoint)
@@ -303,13 +325,13 @@ class ComprehendClient(BaseClient):
         *,
         RecognizerName: str,
         DataAccessRoleArn: str,
-        InputDataConfig: "EntityRecognizerInputDataConfigTypeDef",
+        InputDataConfig: EntityRecognizerInputDataConfigTypeDef,
         LanguageCode: LanguageCodeType,
         VersionName: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
+        VpcConfig: VpcConfigTypeDef = ...,
         ModelKmsKeyId: str = ...,
         ModelPolicy: str = ...
     ) -> CreateEntityRecognizerResponseTypeDef:
@@ -545,6 +567,17 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#detect_syntax)
         """
 
+    def detect_targeted_sentiment(
+        self, *, Text: str, LanguageCode: LanguageCodeType
+    ) -> DetectTargetedSentimentResponseTypeDef:
+        """
+        Inspects the input text and returns a sentiment analysis for each entity
+        identified in the text.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Client.detect_targeted_sentiment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#detect_targeted_sentiment)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -567,7 +600,7 @@ class ComprehendClient(BaseClient):
         VersionName: str = ...,
         ModelKmsKeyId: str = ...,
         DataAccessRoleArn: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> ImportModelResponseTypeDef:
         """
         Creates a new custom model that replicates a source custom model that you
@@ -580,7 +613,7 @@ class ComprehendClient(BaseClient):
     def list_document_classification_jobs(
         self,
         *,
-        Filter: "DocumentClassificationJobFilterTypeDef" = ...,
+        Filter: DocumentClassificationJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListDocumentClassificationJobsResponseTypeDef:
@@ -606,7 +639,7 @@ class ComprehendClient(BaseClient):
     def list_document_classifiers(
         self,
         *,
-        Filter: "DocumentClassifierFilterTypeDef" = ...,
+        Filter: DocumentClassifierFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListDocumentClassifiersResponseTypeDef:
@@ -620,7 +653,7 @@ class ComprehendClient(BaseClient):
     def list_dominant_language_detection_jobs(
         self,
         *,
-        Filter: "DominantLanguageDetectionJobFilterTypeDef" = ...,
+        Filter: DominantLanguageDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListDominantLanguageDetectionJobsResponseTypeDef:
@@ -632,7 +665,7 @@ class ComprehendClient(BaseClient):
         """
 
     def list_endpoints(
-        self, *, Filter: "EndpointFilterTypeDef" = ..., NextToken: str = ..., MaxResults: int = ...
+        self, *, Filter: EndpointFilterTypeDef = ..., NextToken: str = ..., MaxResults: int = ...
     ) -> ListEndpointsResponseTypeDef:
         """
         Gets a list of all existing endpoints that you've created.
@@ -644,7 +677,7 @@ class ComprehendClient(BaseClient):
     def list_entities_detection_jobs(
         self,
         *,
-        Filter: "EntitiesDetectionJobFilterTypeDef" = ...,
+        Filter: EntitiesDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListEntitiesDetectionJobsResponseTypeDef:
@@ -668,7 +701,7 @@ class ComprehendClient(BaseClient):
     def list_entity_recognizers(
         self,
         *,
-        Filter: "EntityRecognizerFilterTypeDef" = ...,
+        Filter: EntityRecognizerFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListEntityRecognizersResponseTypeDef:
@@ -683,7 +716,7 @@ class ComprehendClient(BaseClient):
     def list_events_detection_jobs(
         self,
         *,
-        Filter: "EventsDetectionJobFilterTypeDef" = ...,
+        Filter: EventsDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListEventsDetectionJobsResponseTypeDef:
@@ -697,7 +730,7 @@ class ComprehendClient(BaseClient):
     def list_key_phrases_detection_jobs(
         self,
         *,
-        Filter: "KeyPhrasesDetectionJobFilterTypeDef" = ...,
+        Filter: KeyPhrasesDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListKeyPhrasesDetectionJobsResponseTypeDef:
@@ -711,7 +744,7 @@ class ComprehendClient(BaseClient):
     def list_pii_entities_detection_jobs(
         self,
         *,
-        Filter: "PiiEntitiesDetectionJobFilterTypeDef" = ...,
+        Filter: PiiEntitiesDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListPiiEntitiesDetectionJobsResponseTypeDef:
@@ -725,7 +758,7 @@ class ComprehendClient(BaseClient):
     def list_sentiment_detection_jobs(
         self,
         *,
-        Filter: "SentimentDetectionJobFilterTypeDef" = ...,
+        Filter: SentimentDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListSentimentDetectionJobsResponseTypeDef:
@@ -747,7 +780,7 @@ class ComprehendClient(BaseClient):
     def list_targeted_sentiment_detection_jobs(
         self,
         *,
-        Filter: "TargetedSentimentDetectionJobFilterTypeDef" = ...,
+        Filter: TargetedSentimentDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListTargetedSentimentDetectionJobsResponseTypeDef:
@@ -761,7 +794,7 @@ class ComprehendClient(BaseClient):
     def list_topics_detection_jobs(
         self,
         *,
-        Filter: "TopicsDetectionJobFilterTypeDef" = ...,
+        Filter: TopicsDetectionJobFilterTypeDef = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListTopicsDetectionJobsResponseTypeDef:
@@ -786,14 +819,14 @@ class ComprehendClient(BaseClient):
         self,
         *,
         DocumentClassifierArn: str,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         JobName: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartDocumentClassificationJobResponseTypeDef:
         """
         Starts an asynchronous document classification job.
@@ -805,14 +838,14 @@ class ComprehendClient(BaseClient):
     def start_dominant_language_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         JobName: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartDominantLanguageDetectionJobResponseTypeDef:
         """
         Starts an asynchronous dominant language detection job for a collection of
@@ -825,16 +858,16 @@ class ComprehendClient(BaseClient):
     def start_entities_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
         JobName: str = ...,
         EntityRecognizerArn: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartEntitiesDetectionJobResponseTypeDef:
         """
         Starts an asynchronous entity detection job for a collection of documents.
@@ -846,14 +879,14 @@ class ComprehendClient(BaseClient):
     def start_events_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
         TargetEventTypes: Sequence[str],
         JobName: str = ...,
         ClientRequestToken: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartEventsDetectionJobResponseTypeDef:
         """
         Starts an asynchronous event detection job for a collection of documents.
@@ -865,15 +898,15 @@ class ComprehendClient(BaseClient):
     def start_key_phrases_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
         JobName: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartKeyPhrasesDetectionJobResponseTypeDef:
         """
         Starts an asynchronous key phrase detection job for a collection of documents.
@@ -885,15 +918,15 @@ class ComprehendClient(BaseClient):
     def start_pii_entities_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         Mode: PiiEntitiesDetectionModeType,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
-        RedactionConfig: "RedactionConfigTypeDef" = ...,
+        RedactionConfig: RedactionConfigTypeDef = ...,
         JobName: str = ...,
         ClientRequestToken: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartPiiEntitiesDetectionJobResponseTypeDef:
         """
         Starts an asynchronous PII entity detection job for a collection of documents.
@@ -905,15 +938,15 @@ class ComprehendClient(BaseClient):
     def start_sentiment_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
         JobName: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartSentimentDetectionJobResponseTypeDef:
         """
         Starts an asynchronous sentiment detection job for a collection of documents.
@@ -925,15 +958,15 @@ class ComprehendClient(BaseClient):
     def start_targeted_sentiment_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         LanguageCode: LanguageCodeType,
         JobName: str = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartTargetedSentimentDetectionJobResponseTypeDef:
         """
         Starts an asynchronous targeted sentiment detection job for a collection of
@@ -946,15 +979,15 @@ class ComprehendClient(BaseClient):
     def start_topics_detection_job(
         self,
         *,
-        InputDataConfig: "InputDataConfigTypeDef",
-        OutputDataConfig: "OutputDataConfigTypeDef",
+        InputDataConfig: InputDataConfigTypeDef,
+        OutputDataConfig: OutputDataConfigTypeDef,
         DataAccessRoleArn: str,
         JobName: str = ...,
         NumberOfTopics: int = ...,
         ClientRequestToken: str = ...,
         VolumeKmsKeyId: str = ...,
-        VpcConfig: "VpcConfigTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        VpcConfig: VpcConfigTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> StartTopicsDetectionJobResponseTypeDef:
         """
         Starts an asynchronous topic detection job.
@@ -1045,7 +1078,7 @@ class ComprehendClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/client/#stop_training_entity_recognizer)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Associates a specific tag with an Amazon Comprehend resource.
 
