@@ -48,6 +48,7 @@ __all__ = (
     "SentimentTypeType",
     "SplitType",
     "SyntaxLanguageCodeType",
+    "TargetedSentimentEntityTypeType",
     "ComprehendServiceName",
     "ServiceName",
     "ResourceServiceName",
@@ -125,13 +126,21 @@ PiiEntityTypeType = Literal[
     "AWS_SECRET_KEY",
     "BANK_ACCOUNT_NUMBER",
     "BANK_ROUTING",
+    "CA_HEALTH_NUMBER",
+    "CA_SOCIAL_INSURANCE_NUMBER",
     "CREDIT_DEBIT_CVV",
     "CREDIT_DEBIT_EXPIRY",
     "CREDIT_DEBIT_NUMBER",
     "DATE_TIME",
     "DRIVER_ID",
     "EMAIL",
+    "INTERNATIONAL_BANK_ACCOUNT_NUMBER",
+    "IN_AADHAAR",
+    "IN_NREGA",
+    "IN_PERMANENT_ACCOUNT_NUMBER",
+    "IN_VOTER_NUMBER",
     "IP_ADDRESS",
+    "LICENSE_PLATE",
     "MAC_ADDRESS",
     "NAME",
     "PASSPORT_NUMBER",
@@ -139,12 +148,37 @@ PiiEntityTypeType = Literal[
     "PHONE",
     "PIN",
     "SSN",
+    "SWIFT_CODE",
+    "UK_NATIONAL_HEALTH_SERVICE_NUMBER",
+    "UK_NATIONAL_INSURANCE_NUMBER",
+    "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER",
     "URL",
     "USERNAME",
+    "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER",
+    "VEHICLE_IDENTIFICATION_NUMBER",
 ]
 SentimentTypeType = Literal["MIXED", "NEGATIVE", "NEUTRAL", "POSITIVE"]
 SplitType = Literal["TEST", "TRAIN"]
 SyntaxLanguageCodeType = Literal["de", "en", "es", "fr", "it", "pt"]
+TargetedSentimentEntityTypeType = Literal[
+    "ATTRIBUTE",
+    "BOOK",
+    "BRAND",
+    "COMMERCIAL_ITEM",
+    "DATE",
+    "EVENT",
+    "FACILITY",
+    "GAME",
+    "LOCATION",
+    "MOVIE",
+    "MUSIC",
+    "ORGANIZATION",
+    "OTHER",
+    "PERSON",
+    "PERSONAL_TITLE",
+    "QUANTITY",
+    "SOFTWARE",
+]
 ComprehendServiceName = Literal["comprehend"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -176,6 +210,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -216,7 +251,10 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -252,6 +290,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -293,6 +332,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -319,12 +359,14 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -346,6 +388,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -371,6 +414,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -381,11 +425,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -431,6 +477,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
