@@ -35,8 +35,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     DocumentClassificationJobFilterTypeDef,
@@ -80,7 +79,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListDocumentClassificationJobsPaginator(Boto3Paginator):
+class ListDocumentClassificationJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listdocumentclassificationjobspaginator)
@@ -89,8 +88,8 @@ class ListDocumentClassificationJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "DocumentClassificationJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: DocumentClassificationJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDocumentClassificationJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
@@ -98,7 +97,7 @@ class ListDocumentClassificationJobsPaginator(Boto3Paginator):
         """
 
 
-class ListDocumentClassifiersPaginator(Boto3Paginator):
+class ListDocumentClassifiersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listdocumentclassifierspaginator)
@@ -107,8 +106,8 @@ class ListDocumentClassifiersPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "DocumentClassifierFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: DocumentClassifierFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDocumentClassifiersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
@@ -116,7 +115,7 @@ class ListDocumentClassifiersPaginator(Boto3Paginator):
         """
 
 
-class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
+class ListDominantLanguageDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listdominantlanguagedetectionjobspaginator)
@@ -125,8 +124,8 @@ class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "DominantLanguageDetectionJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: DominantLanguageDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDominantLanguageDetectionJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
@@ -134,7 +133,7 @@ class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
         """
 
 
-class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
+class ListEntitiesDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listentitiesdetectionjobspaginator)
@@ -143,8 +142,8 @@ class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "EntitiesDetectionJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: EntitiesDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEntitiesDetectionJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
@@ -152,7 +151,7 @@ class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
         """
 
 
-class ListEntityRecognizersPaginator(Boto3Paginator):
+class ListEntityRecognizersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listentityrecognizerspaginator)
@@ -161,8 +160,8 @@ class ListEntityRecognizersPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "EntityRecognizerFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: EntityRecognizerFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEntityRecognizersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
@@ -170,7 +169,7 @@ class ListEntityRecognizersPaginator(Boto3Paginator):
         """
 
 
-class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
+class ListKeyPhrasesDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listkeyphrasesdetectionjobspaginator)
@@ -179,8 +178,8 @@ class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "KeyPhrasesDetectionJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: KeyPhrasesDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListKeyPhrasesDetectionJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
@@ -188,7 +187,7 @@ class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
         """
 
 
-class ListSentimentDetectionJobsPaginator(Boto3Paginator):
+class ListSentimentDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listsentimentdetectionjobspaginator)
@@ -197,8 +196,8 @@ class ListSentimentDetectionJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "SentimentDetectionJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: SentimentDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSentimentDetectionJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
@@ -206,7 +205,7 @@ class ListSentimentDetectionJobsPaginator(Boto3Paginator):
         """
 
 
-class ListTopicsDetectionJobsPaginator(Boto3Paginator):
+class ListTopicsDetectionJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/paginators/#listtopicsdetectionjobspaginator)
@@ -215,8 +214,8 @@ class ListTopicsDetectionJobsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filter: "TopicsDetectionJobFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: TopicsDetectionJobFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTopicsDetectionJobsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
